{
    "scan": {
        "analyzer-version-clippy": "1.94.0",
        "analyzer-version-cppcheck": "2.20.0",
        "analyzer-version-gcc": "16.0.1",
        "analyzer-version-gcc-analyzer": "16.0.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "diffbase-analyzer-version-clippy": "1.94.0",
        "diffbase-analyzer-version-cppcheck": "2.20.0",
        "diffbase-analyzer-version-gcc": "16.0.1",
        "diffbase-analyzer-version-gcc-analyzer": "16.0.1",
        "diffbase-analyzer-version-shellcheck": "0.11.0",
        "diffbase-analyzer-version-unicontrol": "0.0.2",
        "diffbase-enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "diffbase-exit-code": 0,
        "diffbase-host": "ip-172-16-1-224.us-west-2.compute.internal",
        "diffbase-known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "diffbase-known-false-positives-rpm": "known-false-positives-0.0.0.20260320.200800.gd35503f.main-1.el9.noarch",
        "diffbase-mock-config": "fedora-rawhide-x86_64",
        "diffbase-project-name": "python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6",
        "diffbase-store-results-to": "/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.tar.xz",
        "diffbase-time-created": "2026-03-26 08:26:04",
        "diffbase-time-finished": "2026-03-26 08:27:44",
        "diffbase-tool": "csmock",
        "diffbase-tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'cppcheck,gcc,shellcheck,clippy,unicontrol' '-o' '/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.src.rpm'",
        "diffbase-tool-version": "csmock-3.8.4.20260302.153719.g8203630-1.el9",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-224.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260320.200800.gd35503f.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6",
        "store-results-to": "/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.tar.xz",
        "time-created": "2026-03-26 08:26:04",
        "time-finished": "2026-03-26 08:27:44",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'cppcheck,gcc,shellcheck,clippy,unicontrol' '-o' '/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpl8qtr3jk/python-podman-5.7.0-1.20260325132222233504.main.23.g58de2c6.src.rpm'",
        "tool-version": "csmock-3.8.4.20260302.153719.g8203630-1.el9"
    },
    "defects": []
}
